#version 150 core

uniform sampler2D tex_color;
uniform sampler2D tex_normal;

uniform float specular;

in vec3 ex_normal;
in vec3 ex_tangent;
in vec3 ex_binormal;

in vec2 ex_texcoord;
in float ex_depth;

out	vec4 out0; // Albedo + Specular
out	vec4 out1; // Normal + Depth
out vec4 out2; // Glow texture

void main(void)
{

	// Retrieving frag colour for writing into the albedo rendertarget
	out0 = texture2D(tex_color, ex_texcoord);

	// Calculating normals in view space for normals rendertarget
	vec3 normal = texture2D(tex_normal, ex_texcoord).xyz;
		
	if(length(normal) > 0.1)
	{
		vec3 normalVec = normal * 2.0 - 1.0;
		mat3 TBN = mat3(ex_tangent, ex_binormal, ex_normal);
		out1.xyz = normalize(TBN * normalVec);
	}
	else
	{
		out1.xyz = normalize(ex_normal);
	}

	//Depth
	out1.w = ex_depth;
	
	
	//Glow texture
	out2 = vec4(out0.w * out0.rgb, 1.0);
}
