#version 150 core

uniform sampler2D tex_albedo;
uniform sampler2D tex_normal;

uniform vec3 view_eyeDir;
	
uniform vec3 view_lightPos;
uniform vec3 view_lightDir;

uniform vec4 lightFalloff;
uniform vec2 spotLightParams;
	
uniform vec3 lightColour;

uniform float farClipDistance;

// Attributes of light
in vec4 ex_view_position;
in vec4 ex_persp_position;
	
out vec4 out0;
	
void main(void)
{
	vec4 ex_persp_position_norm = ex_persp_position / ex_persp_position.w;
    vec2 texCoord = ex_persp_position_norm.xy * 0.5 + 0.5;
	
	vec4 a0 = texture2D(tex_albedo, texCoord); // Attribute 0: Diffuse color+shininess
	vec4 a1 = texture2D(tex_normal, texCoord); // Attribute 1: Normal+depth

	// Attributes
	vec3 diffuseColour = a0.rgb;
	//float specularity = a0.w;
	vec3 normal = a1.xyz;

	// Calculate position of texel on hit object in world space

	//compute screen-space position
    vec3 viewray = vec3( ex_view_position.xy * ( -farClipDistance / ex_view_position.z ), -farClipDistance );
    vec3 view_fragCoord = viewray * a1.w;

	float specularity = 0.33;
	
	// Calculate light direction and distance
	vec3 objToLightVec = view_lightPos - view_fragCoord;
	vec3 objToLightDir = normalize(objToLightVec);

	float len = length(objToLightVec);

	if(lightFalloff.x  >  len)
	{
		vec3 finalLightColour;
		
		//Diffuse
		finalLightColour = max(0.0,dot(objToLightDir, normal)) * lightColour;
		
		//Specular
		vec3 viewDir = - normalize(view_fragCoord);
		vec3 h = normalize(viewDir + objToLightDir);
		finalLightColour += specularity * pow(dot(normal, h),22.0) * lightColour;
	
		float len_sq = len*len;
		float attenuation = dot(lightFalloff.yzw, vec3(1.f, len, len_sq));
		float lightIntensity = 1 / attenuation;
		out0 = vec4( lightIntensity * finalLightColour * diffuseColour , a0.a);
	}
	else
	{
		//Discard
		out0 = vec4(0.0,0.0,0.0,0.0);
	}
}
